@@ -37,6 +37,7 @@ class Dictionary:
     LANGUAGE: str
     TARGET_TAG: str
     TARGET_ATTR: dict[str, str]
+    REPLACES: dict[str, str]
 
     def __str__(self) -> str:
         """Return dictionary's language"""
@@ -50,6 +51,17 @@ class Dictionary:
         ) as response:
             return response
 
+    @classmethod
+    def _replace_terms(cls, meanings: List[str]) -> List[str]:
+        """Replace the unwanted terms of meanings."""
+
+        replaced_meanings = []
+        for meaning in meanings:
+            for from_it, to in cls.REPLACES.items():
+                meaning = meaning.replace(from_it, to)
+            replaced_meanings.append(meaning)
+        return replaced_meanings
+
     @classmethod
     def _soup_meanings(cls, html_tree: str) -> List[str]:
         try:
@@ -65,4 +77,9 @@ class Dictionary:
 
         word = unicodedata.normalize('NFD', word)
         word = re.sub('[\u0300-\u036f]', '', word)
-        return self._soup_meanings(self._search(word).text)
+        search_word_response_html = self._search(word).text
+        if len(meanings := self._soup_meanings(search_word_response_html)) > 0:
+            replaced_meanings = self._replace_terms(meanings)
+            return replaced_meanings
+        else:
+            return []
